@@ -1,4 +1,4 @@
-relmse = function(forecast, forecastbench, true)
+relmse <- function(forecast, forecastbench, true)
 {
   if (length(forecast) != length(true))
       stop("RelMAE: the lengths of input vectors must be the same.")
